/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins;

import java.util.Map;

import org.apache.velocity.VelocityContext;

import com.ecyrd.jspwiki.WikiContext;
import com.intland.codebeamer.persistence.dao.impl.ScmChangeSetDaoImpl;
import com.intland.codebeamer.persistence.dto.ProjectDto;
import com.intland.codebeamer.persistence.dto.ScmChangeSetStatsDto;
import com.intland.codebeamer.wiki.plugins.base.AbstractCodeBeamerWikiPlugin;
import com.intland.codebeamer.wiki.plugins.base.NamedPluginException;

/**
 * Plugin to display a short summary on repository commits.
 *
 * @author <a href="mailto:kao@intland.com">Alexey Kolesnikov</a>
 * @version $Id$
 */
public class CommitStatisticsPlugin extends AbstractCodeBeamerWikiPlugin {
	private static final String LAYOUT_COLUMN = "column";

	private static final String RENDER_TEMPLATE = "commitstatistics-plugin.vm";

	public String execute(WikiContext context, Map params) {
		// parse params
		String layoutType = getParameter(params, "layout", "");
		String template = layoutType.equalsIgnoreCase(LAYOUT_COLUMN) ? LAYOUT_COLUMN : "";

		// Stop rendering if projectID specified is incorrect
		ProjectDto project;
		try {
			project = discoverProject(params, context);
		} catch (NamedPluginException ex) {
			return renderErrorTemplate(ex);
		}

		ScmChangeSetStatsDto commitStats = ScmChangeSetDaoImpl.getInstance().findChangeSetStatsByProject(project.getId());

		// set up Velocity context
		VelocityContext velocityContext = getDefaultVelocityContextFromContext(context);
		velocityContext.put("isCurrentProject", isEnclosingProject());
		velocityContext.put("project", project);
		velocityContext.put("commitStats", commitStats);
		velocityContext.put("template", template);
		velocityContext.put("contextPath", getApplicationContextPath(context));

		// render template
		return renderPluginTemplate(RENDER_TEMPLATE, velocityContext);
	}

}
