/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins;

import java.net.URL;
import java.net.URLConnection;
import java.util.Map;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.commons.lang.math.NumberUtils;
import org.apache.log4j.Logger;
import org.apache.velocity.VelocityContext;

import com.ecyrd.jspwiki.WikiContext;
import com.intland.codebeamer.wiki.plugins.base.AbstractCodeBeamerWikiPlugin;
import com.sun.syndication.feed.synd.SyndFeed;
import com.sun.syndication.io.SyndFeedInput;
import com.sun.syndication.io.XmlReader;

/**
 * Feed inclusion plugin.
 *
 * @author <a href="mailto:aron.gombas@intland.com">Aron Gombas</a>
 * @version $Id$
 */
public class FeedPlugin extends AbstractCodeBeamerWikiPlugin {
	final static private Logger logger = Logger.getLogger(FeedPlugin.class);

	public String execute(WikiContext context, Map params) {
		String url = getParameter(params, "url", "http://blogs.intland.com/main/feed/entries/atom");
		int max = NumberUtils.toInt(getParameter(params, "max"), 10);
		int timeout = NumberUtils.toInt(getParameter(params, "timeout"), 4);

		logger.info("URL: " + url  + " max: " + max + " time-out: " + timeout + " (secs.)");

		try {
			URL feedURL = new URL(url);
			URLConnection openConnection = feedURL.openConnection();
			try {
				// convert timeout to milliseconds
				int iTimeout = timeout * 1000;
				openConnection.setConnectTimeout(iTimeout);
				openConnection.setReadTimeout(iTimeout);
			} catch (Exception ex) {
				logger.warn("Can not set timeout values on connection", ex);
			}

			// fetch feed
			SyndFeedInput in = new SyndFeedInput();
			SyndFeed feed = in.build(new XmlReader(openConnection));

			// trim entries
			if (feed.getEntries().size() > max) {
				for (int i = feed.getEntries().size() - 1; i >= max; i--) {
					feed.getEntries().remove(i);
				}
			}

			// set up Velocity context
			VelocityContext velocityContext = getDefaultVelocityContextFromContext(context);
			velocityContext.put("feed", feed);
			velocityContext.put("feedDetails", getParameter(params, "feedDetails", "false"));
			velocityContext.put("entryDetails", getParameter(params, "entryDetails", "false"));
			velocityContext.put("contextPath", getApplicationContextPath(context));

			// render template
			return renderPluginTemplate("feed-plugin.vm", velocityContext);
		} catch (Throwable ex) {
			logger.warn(ex.toString(), ex);

			return "<span class=\"wiki-error\">Failed to fetch feed from \"" + StringEscapeUtils.escapeHtml(url) + "\"<BR />" +
				StringEscapeUtils.escapeHtml(ex.toString()) + "</span>";
		}
	}
}
