/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.velocity.VelocityContext;

import com.ecyrd.jspwiki.WikiContext;
import com.intland.codebeamer.manager.TrackerManager;
import com.intland.codebeamer.persistence.dao.TrackerItemDao;
import com.intland.codebeamer.persistence.dto.ProjectDto;
import com.intland.codebeamer.persistence.dto.TrackerDto;
import com.intland.codebeamer.persistence.dto.TrackerStatsDto;
import com.intland.codebeamer.persistence.dto.UserDto;
import com.intland.codebeamer.persistence.dto.WikiPageDto;
import com.intland.codebeamer.wiki.WikiMarkupProcessor;
import com.intland.codebeamer.wiki.plugins.base.AbstractCodeBeamerWikiPlugin;
import com.intland.codebeamer.wiki.plugins.base.NamedPluginException;

/**
 * Plugin to display the overall statistics on project which the current wiki page belongs to.
 *
 * @author <a href="mailto:kao@intland.com">Alexey Kolesnikov</a>
 * @version $Id$
 */
public class ProjectInfoPlugin extends AbstractCodeBeamerWikiPlugin {
	private static final String RENDER_TEMPLATE = "projectinfo-plugin.vm";

	public String execute(WikiContext context, Map params) {
		// get beans from wiki context
		UserDto user = getUserFromContext(context);
		WikiPageDto page = getPageFromContext(context);

		HttpServletRequest httpRequest = context.getHttpRequest();

		// Stop rendering if projectID specified is incorrect
		ProjectDto project;
		try {
			project = discoverProject(params, context);
		} catch (NamedPluginException ex) {
			return renderErrorTemplate(ex);
		}

		String projectDescription;
		String df = project.getDescriptionFormat(); // Is null for plain text!
		String descriptionText = project.getDescription();
		if (df != null && df.equals(WikiMarkupProcessor.TEXT_TYPE_WIKI)) {
			// Workaround for situation when wiki page belongs to tracker item:
			// in this case getPageFromContext(context) returns null
			if (page != null) {
				projectDescription = WikiMarkupProcessor.getInstance().transformToHtml(httpRequest, descriptionText,
						WikiMarkupProcessor.TEXT_TYPE_WIKI, false, false, page, user);
			} else {
				projectDescription = context.getEngine().textToHTML(context, descriptionText);
			}
		} else {
			projectDescription = descriptionText;
		}

		// Check if the homepage url is correct
		String homePageURL = "";
		try {
			URL url = new URL(project.getHomePage());
			homePageURL = url.toExternalForm();
		} catch (MalformedURLException ex) {
		}

		List<TrackerStatsDto> data = TrackerManager.getInstance().getTrackerItemStatsByTracker(user, project, null, true, Boolean.FALSE);
		TrackerStatsDto result = null;
		if (data != null && data.size() == 1) {
			result = data.get(0);
		}

		// set up Velocity context
		VelocityContext velocityContext = getDefaultVelocityContextFromContext(context);
		velocityContext.put("isCurrentProject", isEnclosingProject());
		velocityContext.put("project", project);
		velocityContext.put("summary", result);
		velocityContext.put("projectDescription", projectDescription);
		velocityContext.put("homePageURL", homePageURL);
		velocityContext.put("BUG_TYPE", new Integer(TrackerDto.BUG));
		velocityContext.put("TASK_TYPE", new Integer(TrackerDto.TASK));
		velocityContext.put("TF_NOFILTER", new Integer(TrackerItemDao.TF_NOFILTER));
		velocityContext.put("TF_DELAYED", new Integer(TrackerItemDao.TF_DELAYED));
		velocityContext.put("TF_OVERTIME", new Integer(TrackerItemDao.TF_OVERTIME));
		velocityContext.put("TF_OVERDUE", new Integer(TrackerItemDao.TF_OVERDUE));
		velocityContext.put("contextPath", getApplicationContextPath(context));

		// render template
		return renderPluginTemplate(RENDER_TEMPLATE, velocityContext);
	}
}
