/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.math.NumberUtils;
import org.apache.velocity.VelocityContext;

import com.ecyrd.jspwiki.WikiContext;
import com.intland.codebeamer.manager.ForumManager;
import com.intland.codebeamer.manager.ForumPostManager;
import com.intland.codebeamer.persistence.dto.ForumDto;
import com.intland.codebeamer.persistence.dto.ProjectDto;
import com.intland.codebeamer.persistence.dto.UserDto;
import com.intland.codebeamer.wiki.plugins.base.AbstractCodeBeamerWikiPlugin;
import com.intland.codebeamer.wiki.plugins.base.NamedPluginException;

/**
 * Plugin to display resent news on project forums.
 *
 * @author <a href="mailto:kao@intland.com">Alexey Kolesnikov</a>
 * @version $Id$
 */
public class RecentNewsPlugin extends AbstractCodeBeamerWikiPlugin {
	private static final String RENDER_TEMPLATE = "recentnews-plugin.vm";

	public String execute(WikiContext context, Map params) {
		// get beans from wiki context
		UserDto user = getUserFromContext(context);

		// parse params
		int max = NumberUtils.toInt(getParameter(params, "max"), 5);

		ProjectDto project;
		try {
			project = discoverProject(params, context);
		} catch (NamedPluginException ex) {
			return renderErrorTemplate(ex);
		}

		List forumIds = ForumManager.getInstance().findForumIdsByUserAndProject(user, project);
		List typeIds = new ArrayList();
		typeIds.add(new Integer(ForumDto.ANNOUNCEMENTS));
		typeIds.add(new Integer(ForumDto.NEWS));

		List news = ForumPostManager.getInstance().findRecentlyPostedByForum(user, forumIds, typeIds, max);

		// set up Velocity context
		VelocityContext velocityContext = getDefaultVelocityContextFromContext(context);
		velocityContext.put("isCurrentProject", isEnclosingProject());
		velocityContext.put("project", project);
		velocityContext.put("news", news);
		velocityContext.put("contextPath", getApplicationContextPath(context));

		// render template
		return renderPluginTemplate(RENDER_TEMPLATE, velocityContext);
	}
}
