/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins;

import java.util.List;
import java.util.Map;

import org.apache.velocity.VelocityContext;

import com.ecyrd.jspwiki.WikiContext;
import com.intland.codebeamer.manager.TrackerItemManager;
import com.intland.codebeamer.manager.TrackerManager;
import com.intland.codebeamer.persistence.dao.TrackerItemDao;
import com.intland.codebeamer.persistence.dto.UserDto;
import com.intland.codebeamer.persistence.dto.WikiPageDto;
import com.intland.codebeamer.wiki.plugins.base.AbstractCodeBeamerWikiPlugin;

/**
 * Plugin to demonstrate using the Service Layer in CodeBeamer.
 * Only for education purposes.
 *
 * @author <a href="mailto:aron.gombas@intland.com">Aron Gombas</a>
 * @version $Id$
 */
public class ServiceLayerDemoPlugin extends AbstractCodeBeamerWikiPlugin {
	public String execute(WikiContext context, Map params) {
		// get beans from wiki context
		UserDto user = getUserFromContext(context);
		WikiPageDto page = getPageFromContext(context);

		// parse params (they default to false)
		boolean includeAssignedTo = Boolean.valueOf((String)params.get("assigedTo")).booleanValue();
		boolean includeSubmittedBy = Boolean.valueOf((String)params.get("submittedBy")).booleanValue();
		boolean includeSupervisedBy = Boolean.valueOf((String)params.get("supervisedBy")).booleanValue();
		if(!includeAssignedTo && !includeSubmittedBy && !includeSupervisedBy) {
			// set at least includeAssignedTo to true
			includeAssignedTo = true;
		}

		// find all trackers in the current project
		List trackers = TrackerManager.getInstance().findByProject(user, page.getProject());

		// find all tracker items in those trackers that are assigned-to or submitted-by by the current user
		List trackerItems = TrackerItemManager.getInstance().findByOwner(user, trackers, TrackerItemDao.TF_NOFILTER, includeAssignedTo, includeSubmittedBy, includeSupervisedBy, user);

		// set up Velocity context
		VelocityContext velocityContext = getDefaultVelocityContextFromContext(context);
		velocityContext.put("trackerItems", trackerItems);

		// render template
		return renderPluginTemplate("servicelayerdemo-plugin.vm", velocityContext);
	}
}
