/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.apache.velocity.VelocityContext;

import com.ecyrd.jspwiki.WikiContext;
import com.intland.codebeamer.persistence.dao.impl.ProjectPreferencesDaoImpl;
import com.intland.codebeamer.persistence.dao.impl.SourceFileDaoImpl;
import com.intland.codebeamer.persistence.dto.FileGroupDto;
import com.intland.codebeamer.persistence.dto.ProjectDto;
import com.intland.codebeamer.persistence.dto.ProjectPreferencesDto;
import com.intland.codebeamer.wiki.plugins.base.AbstractCodeBeamerWikiPlugin;
import com.intland.codebeamer.wiki.plugins.base.NamedPluginException;

/**
 * Plugin to display a summary statistic on source code related to the project.
 *
 * @author <a href="mailto:kao@intland.com">Alexey Kolesnikov</a>
 * @version $Id$
 */
public class SourceCodeSummaryPlugin extends AbstractCodeBeamerWikiPlugin {
	private static final String RENDER_TEMPLATE = "sourcecodesummary-plugin.vm";

	public String execute(WikiContext context, Map params) {
		ProjectDto project;
		try {
			project = discoverProject(params, context);
		} catch (NamedPluginException ex) {
			return renderErrorTemplate(ex);
		}

		// Get filegroups for project
		ProjectPreferencesDto preferences = ProjectPreferencesDaoImpl.getInstance().findByProjectId(project.getId());
		Map fileGroups = new HashMap();
		if (preferences != null) {
			for (Iterator it = preferences.getSourceFileGroups().iterator(); it.hasNext();) {
				FileGroupDto fg = (FileGroupDto) it.next();
				fileGroups.put(fg.getType(), fg.getDescription());
			}
		}

		List sourceCodeStats = SourceFileDaoImpl.getInstance().findSourceFilesStatsByTypeId(project.getId());

		// set up Velocity context
		VelocityContext velocityContext = getDefaultVelocityContextFromContext(context);
		velocityContext.put("isCurrentProject", isEnclosingProject());
		velocityContext.put("project", project);
		velocityContext.put("sourceCodeStats", sourceCodeStats);
		velocityContext.put("fileGroups", fileGroups);
		velocityContext.put("contextPath", getApplicationContextPath(context));

		// render template
		return renderPluginTemplate(RENDER_TEMPLATE, velocityContext);
	}
}
