/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins;

import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;
import org.apache.velocity.VelocityContext;

import com.ecyrd.jspwiki.WikiContext;
import com.intland.codebeamer.manager.TrackerItemManager;
import com.intland.codebeamer.persistence.dto.TrackerItemDto;
import com.intland.codebeamer.persistence.dto.TrackerItemHistoryEntryDto;
import com.intland.codebeamer.persistence.dto.UserDto;
import com.intland.codebeamer.wiki.plugins.base.AbstractCodeBeamerWikiPlugin;

/**
 * Plugin to create a TeamTrack like state change history graph for a task.
 *
 * @author <a href="mailto:Klaus.Mehling@intland.com">Klaus Mehling</a>
 * @version $Id$
 */
public class TrackerItemStateHistoryPlugin extends AbstractCodeBeamerWikiPlugin {
	public static final  Logger log = Logger.getLogger(TrackerItemStateHistoryPlugin.class);
	private static final String PLUGIN_TEMPLATE = "tracker-item-state-history-plugin.vm";
	private static final String PARAM_ID = "id";

	public String execute(WikiContext context, Map params) {
		UserDto user = getUserFromContext(context);
		String trackerItemId = getParameter(params, PARAM_ID);

		if (StringUtils.isNotBlank(trackerItemId)) {
			try {
				Integer taskId  = Integer.valueOf(trackerItemId);
				TrackerItemManager manager = TrackerItemManager.getInstance();
				List history = manager.getStateChangeHistory(user, taskId);

				if (history != null && !history.isEmpty()) {
					TrackerItemDto trackerItem = ((TrackerItemHistoryEntryDto) history.get(history.size() -1)).getTrackerItem();

					// set up Velocity context
					VelocityContext velocityContext = getDefaultVelocityContextFromContext(context);
					velocityContext.put("item", trackerItem);
					velocityContext.put("history", history);
					velocityContext.put("contextPath", getContextPath(context)); // TODO why not using this? velocityContext.put("contextPath", getApplicationContextPath(context));

					// render template
					return renderPluginTemplate(PLUGIN_TEMPLATE, velocityContext);
				}
			} catch (Throwable ex) {
				log.error("execute failed", ex);
				return ex.toString();
			}
		}

		return trackerItemId;
	}

	protected String getContextPath(WikiContext context) {
		String contextPath = "";
		if (context.getHttpRequest() != null) {
			contextPath = context.getHttpRequest().getContextPath();
		}
		return contextPath;
	}
}
