/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.velocity.VelocityContext;

import com.ecyrd.jspwiki.plugin.PluginException;
import com.intland.codebeamer.manager.SubscriptionManager;
import com.intland.codebeamer.manager.TrackerManager;
import com.intland.codebeamer.manager.TrackerViewManager;
import com.intland.codebeamer.persistence.dto.ProjectDto;
import com.intland.codebeamer.persistence.dto.SubscriptionDto;
import com.intland.codebeamer.persistence.dto.TrackerDto;
import com.intland.codebeamer.persistence.dto.TrackerStatsDto;
import com.intland.codebeamer.persistence.dto.UserDto;
import com.intland.codebeamer.persistence.util.PersistenceUtils;
import com.intland.codebeamer.remoting.GroupType;
import com.intland.codebeamer.wiki.plugins.base.AutoWiringCodeBeamerPlugin;
import com.intland.codebeamer.wiki.plugins.base.NamedPluginException;

/**
 * Plugin to generate a list of trackers with their statistics.
 *
 * @author <a href="mailto:aron.gombas@intland.com">Aron Gombas</a>
 * @version $Id$
 */
public class TrackerListPlugin extends AutoWiringCodeBeamerPlugin {
	@Override
	public void populateContext(VelocityContext velocityContext, Map params) throws PluginException {
		UserDto user = getUser();
		ProjectDto project = discoverProject(params, getWikiContext(), true);
		if (project == null) {
			throw new NamedPluginException(this, "The projectId parameter must be specified when using outside of any project context");
		}

		// calculates aggregated statistics when project is NULL
		List<TrackerStatsDto> trackerStats = findTrackerStats(user, project);
		Map<Integer, SubscriptionDto> trackerSubscriptionsMap = findTrackerSubscriptions(user, trackerStats);

		velocityContext.put("request", wikiContext.getHttpRequest());
		velocityContext.put("trackerStats", trackerStats);
		for(Map.Entry<String, Integer> entry : findTrackerViewConstants().entrySet()) {
			velocityContext.put(entry.getKey(), entry.getValue());
		}
		velocityContext.put("GroupType_TRACKER", new Integer(GroupType.TRACKER));
		velocityContext.put("trackerSubscriptionsMap", trackerSubscriptionsMap);
	}

	@Override
	public String getTemplateFilename() {
		return "tracker-list-plugin.vm";
	}

	/**
	 * Returns the trackers in the given project that are visible for the user.
	 */
	protected List<TrackerStatsDto> findTrackerStats(UserDto user, ProjectDto project) {
		boolean groupByProject = false;

		// get tracker stats
		List<TrackerStatsDto> data = TrackerManager.getInstance().getTrackerItemStatsByTracker(user, project, null, groupByProject, Boolean.FALSE);
		List<TrackerStatsDto> result = null;
		if (groupByProject) {
			if (data != null && data.size() == 1) {
				result = PersistenceUtils.createList(data.get(0));
			} else {
				result = null;
			}
		} else {
			result = data;
		}

		return result;
	}

	/**
	 * Returns the user's subscription settings for the trackers passed.
	 */
	protected Map<Integer,SubscriptionDto> findTrackerSubscriptions(UserDto user, List<TrackerStatsDto> trackerStats) {
		List<TrackerDto> trackers = new ArrayList<TrackerDto>(trackerStats.size());
		for(TrackerStatsDto trackerStat : trackerStats) {
			trackers.add(trackerStat.getTracker());
		}

		Map<Integer,SubscriptionDto> entitySubscriptions = SubscriptionManager.getInstance().findSubscriptionsByUserAndEntities(user, new Integer(GroupType.TRACKER), trackers);
		return entitySubscriptions;
	}

	/**
	 * Returns the constants to add to the model.
	 */
	protected Map<String, Integer> findTrackerViewConstants() {
		Map<String, Integer> model = new HashMap<String, Integer>(5);

		model.put("ROOT_VIEW", TrackerViewManager.ATV_OPEN_TOPLEVEL_ITEMS);
		model.put("OPEN_VIEW", TrackerViewManager.ATV_OPEN);
		model.put("ALL_ITEMS_VIEW", TrackerViewManager.ATV_ALL_ITEMS);
		model.put("ASSIGNED_TO_ME_VIEW", TrackerViewManager.ATV_ASSIGNED_TO_ME);
		model.put("SUBMITTED_BY_ME_VIEW", TrackerViewManager.ATV_SUBMITTED_BY_ME);

		return model;
	}
}
