/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 *
 * Created: 02.08.2007
 */

package com.intland.codebeamer.wiki.plugins.base;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.Writer;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.commons.lang.time.FastDateFormat;

import com.ecyrd.jspwiki.plugin.PluginException;
import com.intland.codebeamer.manager.UserManager;
import com.intland.codebeamer.persistence.dao.ArtifactDao;
import com.intland.codebeamer.persistence.dao.BinaryContentDao;
import com.intland.codebeamer.persistence.dao.impl.ArtifactDaoImpl;
import com.intland.codebeamer.persistence.dao.impl.BinaryContentDaoImpl;
import com.intland.codebeamer.persistence.dto.ArtifactCommentDto;
import com.intland.codebeamer.persistence.dto.ArtifactDto;
import com.intland.codebeamer.persistence.dto.BinaryStreamDto;
import com.intland.codebeamer.persistence.dto.UserDto;
import com.intland.codebeamer.servlet.docs.DocumentScc;
import com.intland.codebeamer.wiki.CodeBeamerWikiContext;
import com.intland.codebeamer.wiki.WikiInlinedResourceProvider;

/**
 * @author <a href="mailto:zsolt.koppany@intland.com">Zsolt Koppany</a>
 * @version $Id$
 */
public abstract class AbstractArtifactAwareWikiPlugin extends AbstractCodeBeamerWikiPlugin {
	abstract protected Integer getArtifactId();
	abstract protected String getSrc();
	abstract protected String getIconName();

	private final static ArtifactDao artifactDao = ArtifactDaoImpl.getInstance();
	private final static BinaryContentDao binaryContentDao = BinaryContentDaoImpl.getInstance();

	private ArtifactDto document;

	protected ArtifactDto getArtifact() {
		return document;
	}

	protected InputStream getInputStream(CodeBeamerWikiContext context) throws Exception {
		URL url = null;
		InputStream retval = null;

		UserDto user = context.getUser();

		Integer doc_id = getArtifactId();

		if (doc_id != null) {
			DocumentScc documentScc = DocumentScc.getInstance("db");
			document = artifactDao.findById(user, doc_id);
			if (document != null) {
				File file = documentScc.checkout(user, document);
				retval = new FileInputStream(file);
			} else {
				Integer userId = user == null ? new Integer(-1) : user.getId();
				String msg = "Document (id: " + doc_id + ") not accessible by user (id: " + userId + ")";
				throw new PluginException(msg);
			}
		} else {
			String src = getSrc();
			if (src != null) {
				// first, assume that src is a URL
				try {
					url = new URL(src);
					retval = url.openStream();
				} catch(MalformedURLException urlex) {
					// Trying from classpath
					try {
						retval = getClass().getResourceAsStream(src);
					} catch (Throwable ex) {
					}

					if (retval == null) {
						// if it wasn't a valid URL, try it as a file reference
						// this would work, for instance for "C:\foo.xls" or "\\myserver\share\foo.xls"
						try {
							retval = new FileInputStream(src);
						} catch(FileNotFoundException ex) {
							// fall back to using it as attachment reference
							ArtifactCommentDto attachment = (ArtifactCommentDto)WikiInlinedResourceProvider.getInstance().getArtifactOrAttachmentByReference(context, src);
							BinaryStreamDto blob = binaryContentDao.loadArtifactCommentBlob(attachment);
							retval = (blob == null ? null : blob.getInputStream());
						}
					}
				}
			} else {
				throw new PluginException("Either 'src' or 'id' parameter must be used");
			}
		}

		if (retval != null) {
			retval = new BufferedInputStream(retval);
		}
		return retval;
	}

	protected void writeLiveEditControl(UserDto user, Writer bw, String contextPath) throws IOException {
		if (document != null) {
			Date lastModifiedAt = document.getLastModifiedAt() == null ? document.getCreatedAt() : document.getLastModifiedAt();
			String lastModifiedAtString = null;
			String lastModifiedByString = null;
			if (user != null) {
				FastDateFormat dateFormat = user.getDateTimeFormat();
				lastModifiedAtString = dateFormat.format(lastModifiedAt);
				lastModifiedByString = UserManager.getInstance().getAliasName(user);
			} else {
				lastModifiedAtString = lastModifiedAt.toString();
			}

			String title = "[DOC: " + document.getId() + "] Project: " + document.getProject().getName()
				+ "; Document: " + document.getPath() + "; Last modified: " + lastModifiedAtString;
			if (lastModifiedByString != null) {
				title += " (by " + lastModifiedByString + ")";
			}

			bw.write(showIcon(getIconName(), contextPath)
				+ "<a href=\"" + contextPath + document.getUrlLink() + "\" "
				+ "title=\"" + StringEscapeUtils.escapeHtml(title) + "\">"
				+ StringEscapeUtils.escapeHtml(document.getName()) + "</a>");

			if (document.isWritable()) {
				bw.write("<a href=\"" + contextPath + "/docs/jnlp/cbapplet.jnlp?doc_id=" + document.getId() + "\" "
					+ "title=\"" + StringEscapeUtils.escapeHtml("Live Edit") + "\">"
					+ showIcon("live_edit.gif", contextPath)
					+ "</a>");
			}
		}
	}

	protected String getContextPath(CodeBeamerWikiContext context) {
		String contextPath = "";
		if (context.getHttpRequest() != null) {
			HttpServletRequest request = context.getHttpRequest();
			contextPath = request.getContextPath();
		}
		return contextPath;
	}

	protected String showIcon(String iconName, String contextPath) {
		return "<img src=\"" + contextPath + "/images/" + iconName + "\" border=\"0\" width=\"16\" height=\"16\" />";
	}
}
