/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins.dataset.producer;

import java.util.List;
import java.util.Map;

import org.jfree.data.general.Dataset;
import org.jfree.data.time.Day;
import org.jfree.data.time.TimeSeries;
import org.jfree.data.time.TimeSeriesCollection;

import com.ecyrd.jspwiki.plugin.PluginException;
import com.intland.codebeamer.persistence.dao.ChartDao;
import com.intland.codebeamer.persistence.dto.ChartCommitTrendDto;
import com.intland.codebeamer.persistence.dto.ProjectDto;
import com.intland.codebeamer.persistence.util.PersistenceUtils;
import com.intland.codebeamer.wiki.plugins.dataset.WikiDataSetProducer;

/**
 * @author <a href="mailto:kao@intland.com">Alexey Kolesnikov</a>
 * @version $Id$
 */
public class CommitTrendProducer extends AbstractWikiDataSetProducer implements WikiDataSetProducer {
	private ChartDao chartDao;

	public Dataset produce(Map<String, String> params) throws PluginException  {
		ProjectDto project = getProject();
		if(project == null) {
			throw new PluginException("Parameter 'projectId' is required");
		}
		boolean groupByUser = Boolean.parseBoolean(params.get("groupByUser"));

		// gather
		List<ChartCommitTrendDto> commitStats = chartDao.getCommitTrend(PersistenceUtils.createSingleItemList(project.getId()), Boolean.valueOf(groupByUser), getStartDate(), getEndDate());

		// convert
		TimeSeriesCollection timeSeriesCollection = new TimeSeriesCollection();
		for (ChartCommitTrendDto commitStat : commitStats) {
			String key = (commitStat.getUserName() != null) ? commitStat.getUserName() : "Commits";

			TimeSeries timeSeries = timeSeriesCollection.getSeries(key);
			if(timeSeries == null) {
				timeSeries = new TimeSeries(key);
				timeSeriesCollection.addSeries(timeSeries);
			}

			timeSeries.add(new Day(commitStat.getDate()), commitStat.getCommitCount());
		}

		return timeSeriesCollection;
	}

	public void setChartDao(ChartDao chartDao) {
		this.chartDao = chartDao;
	}
}
