/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins.dataset.producer;

import java.util.List;
import java.util.Map;

import org.jfree.data.general.Dataset;
import org.jfree.data.time.Day;
import org.jfree.data.time.TimeSeries;
import org.jfree.data.time.TimeSeriesCollection;

import com.ecyrd.jspwiki.plugin.PluginException;
import com.intland.codebeamer.persistence.dao.impl.ChartDaoImpl;
import com.intland.codebeamer.persistence.dto.ChartSourceCodeTrendDto;
import com.intland.codebeamer.persistence.dto.ProjectDto;
import com.intland.codebeamer.persistence.util.PersistenceUtils;
import com.intland.codebeamer.wiki.plugins.dataset.WikiDataSetProducer;

/**
 * @author <a href="mailto:kao@intland.com">Alexey Kolesnikov</a>
 * @version $Id$
 */
public class SourceCodeChangeTrendProducer extends AbstractWikiDataSetProducer implements WikiDataSetProducer {
	public Dataset produce(Map<String, String> params) throws PluginException {
		ProjectDto project = getProject();
		if(project == null) {
			throw new PluginException("Parameter 'projectId' is required");
		}

		// gather
		List<ChartSourceCodeTrendDto> sourceCodeChanges = ChartDaoImpl.getInstance().getSourceCodeTrend(PersistenceUtils.createSingleItemList(project.getId()), getStartDate(), getEndDate());

		// convert
		TimeSeries filesTimeSeries = new TimeSeries("Files");
		TimeSeries totalLinesTimeSeries2 = new TimeSeries("Lines");
		TimeSeries codeLinesTimeSeries3 = new TimeSeries("Program Lines");
		TimeSeries commentLinesTimeSeries4 = new TimeSeries("Comment Lines");
		TimeSeries statementsTimeSeries5 = new TimeSeries("Statements");
		for (ChartSourceCodeTrendDto sourceCodeChange : sourceCodeChanges) {
			Day day = new Day(sourceCodeChange.getDate());

			filesTimeSeries.add(day, sourceCodeChange.getFiles());
			totalLinesTimeSeries2.add(day, sourceCodeChange.getTotalLines());
			codeLinesTimeSeries3.add(day, sourceCodeChange.getCodeLines());
			commentLinesTimeSeries4.add(day, sourceCodeChange.getCommentLines());
			statementsTimeSeries5.add(day, sourceCodeChange.getStatements());
		}

		TimeSeriesCollection timeSeriesCollection = new TimeSeriesCollection();
		timeSeriesCollection.addSeries(filesTimeSeries);
		timeSeriesCollection.addSeries(totalLinesTimeSeries2);
		timeSeriesCollection.addSeries(codeLinesTimeSeries3);
		timeSeriesCollection.addSeries(commentLinesTimeSeries4);
		timeSeriesCollection.addSeries(statementsTimeSeries5);
		return timeSeriesCollection;
	}
}
