/*
 * Copyright by Intland Software
 *
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Intland Software. ("Confidential Information"). You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Intland.
 */
package com.intland.codebeamer.wiki.plugins.dataset.producer;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.jfree.data.category.DefaultCategoryDataset;
import org.jfree.data.general.Dataset;

import com.ecyrd.jspwiki.plugin.PluginException;
import com.intland.codebeamer.manager.TrackerManager;
import com.intland.codebeamer.persistence.dao.impl.ChartDaoImpl;
import com.intland.codebeamer.persistence.dao.impl.TrackerLayoutDaoImpl;
import com.intland.codebeamer.persistence.dto.ChartTrackerItemsByStatusAndSeverityDto;
import com.intland.codebeamer.persistence.dto.ProjectDto;
import com.intland.codebeamer.persistence.dto.TrackerChoiceOptionDto;
import com.intland.codebeamer.persistence.dto.TrackerDto;
import com.intland.codebeamer.persistence.dto.UserDto;
import com.intland.codebeamer.persistence.util.PersistenceUtils;
import com.intland.codebeamer.wiki.plugins.dataset.WikiDataSetProducer;

/**
 * @author <a href="mailto:aron.gombas@intland.com">Aron Gombas</a>
 * @version $Id$
 */
public class TrackerItemsByStatusAndSeverityProducer extends AbstractWikiDataSetProducer implements WikiDataSetProducer {
	public Dataset produce(Map<String, String> params) throws PluginException {
		UserDto user = getUser();
		ProjectDto project = getProject();
		if(project == null) {
			throw new PluginException("Parameter 'projectId' is required");
		}

		List<Integer> trackerIds = parseCommaSeparatedIds(params.get("trackerId"));
		List<TrackerDto> trackers = trackerIds.isEmpty() ? TrackerManager.getInstance().findByProject(user, project) : TrackerManager.getInstance().findById(user, trackerIds);

		// gather
		Map<Integer, TrackerChoiceOptionDto> statuses = new HashMap();
		for(TrackerDto tracker : trackers) {
			for(TrackerChoiceOptionDto status : TrackerLayoutDaoImpl.getInstance().findStatusOptionsByTracker(tracker.getId())) {
				statuses.put(status.getId(), status);
			}
		}

		List<ChartTrackerItemsByStatusAndSeverityDto> trackerItemsBySeverities = ChartDaoImpl.getInstance().getTrackerItemsByStatusAndSeverity(PersistenceUtils.createSingleItemList(project.getId()), PersistenceUtils.grabIds(statuses.values()));

		// convert
		DefaultCategoryDataset defaultCategoryDataset = new DefaultCategoryDataset();
		for (ChartTrackerItemsByStatusAndSeverityDto trackerItemsBySeverity : trackerItemsBySeverities) {
			Map<Integer, Long> statusCounts = trackerItemsBySeverity.getStatusCounts();
			for(Integer statusId : statusCounts.keySet()) {
				defaultCategoryDataset.addValue(statusCounts.get(statusId), trackerItemsBySeverity.getSeverity().getName(), statuses.get(statusId).getName());
			}
			defaultCategoryDataset.addValue(trackerItemsBySeverity.getTotal(), trackerItemsBySeverity.getSeverity().getName(), "Total");
		}

		return defaultCategoryDataset;
	}
}